function [fbout] = applyfbank(signal,fbank)
%[fbout] = applyfbank(signal,fbank)
%
%APPLYFBANK
%
% This function applies the filterbank in the matrix fbank to the signals
% in the matrix signal. Signal should have each COLUMN as a frame
% to be analyzed, and the framelength should be compatible with
% the number of columns in fbank (ie it should be twice as many).
%
% fbout is a matrix holding the filterbank output, one column per frame
% and one row per channel in the filterbank

[framelen,numframes] = size(signal);
[numchans,fbN]  = size(fbank);

fftN = 2^ceil(log(framelen)/log(2));

assert(2*fbN == fftN);

newsig = zeros(fftN,numframes);
newsig(1:framelen,:) = signal; %newsig(framelen+1:fftN,:) are padded with zero.

fftsig = abs(fft(newsig));
fbout = fbank*fftsig(1:(fftN/2),:);







