function [newsigs] = applywins(signals, wind)
%[newsigs] = applywins(signals, wind)
%
%APPLYWINS
%  Applies a window function to many signals.
%  The input matrix signals has each COLUMN as a signal
%  the output newsigs is obtained windowing each col by the same window.
%
%  wind is an optional window parameter, if it is absent or if it is
%  the scalar 0 or if it is a vector of any size other than the number
%  of rows in signals then no window is applied and the output is unchanged
%
%  if wind is the scalar 1 then a hamming window is applied to each frame
%  if wind is the scalar 2 then a hanning window is applied to each frame
%  if wind is -1 then an inverse hamming window is applied to each frame
%  if wind is -2 then an inverse hanning window is applied to each frame


[windl,sigs] = size(signals);
newsigs = zeros(windl,sigs);

if(nargin<2) wind=0; end;
wind=wind(:);
if(length(wind)==windl)
  thewin = wind;
else
  if(wind==0) newsigs=signals; return;
  elseif(wind==1) thewin=hamming(windl);
  elseif(wind==2) thewin=hanning(windl);
  elseif(wind==-1) thewin=1./hamming(windl);
  elseif(wind==-2) thewin=1./hanning(windl);
  else newsigs=signals; return;
  end
end

newsigs = signals.*(thewin*ones(1,sigs));





